/* Generated by re2c 1.2.1 */
#line 1 "implicit.re"
#include "yaml.h"

char *
Ryaml_find_implicit_tag(str, len)
  const char *str;
  size_t len;
{
  /* This bit was taken from implicit.re, which is in the Syck library.
   *
   * Copyright (C) 2003 why the lucky stiff */

  const char *cursor, *marker;
  cursor = str;


#line 19 "implicit.c"
{
	char yych;
	yych = *cursor;
	switch (yych) {
	case 0x00:	goto yy2;
	case '+':	goto yy6;
	case '-':	goto yy7;
	case '.':	goto yy8;
	case '0':	goto yy9;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy10;
	case '<':	goto yy11;
	case '=':	goto yy12;
	case 'F':	goto yy13;
	case 'N':	goto yy14;
	case 'O':	goto yy15;
	case 'T':	goto yy16;
	case 'Y':	goto yy17;
	case 'f':	goto yy18;
	case 'n':	goto yy19;
	case 'o':	goto yy20;
	case 't':	goto yy21;
	case 'y':	goto yy22;
	case '~':	goto yy23;
	default:	goto yy4;
	}
yy2:
	++cursor;
#line 58 "implicit.re"
	{   return "null"; }
#line 57 "implicit.c"
yy4:
	++cursor;
yy5:
#line 104 "implicit.re"
	{   return "str"; }
#line 63 "implicit.c"
yy6:
	yych = *(marker = ++cursor);
	switch (yych) {
	case '.':	goto yy24;
	case '0':	goto yy26;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy27;
	default:	goto yy5;
	}
yy7:
	yych = *(marker = ++cursor);
	switch (yych) {
	case '.':	goto yy29;
	case '0':	goto yy26;
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy27;
	default:	goto yy5;
	}
yy8:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy30;
	case ',':	goto yy32;
	case '.':	goto yy34;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy36;
	case 'E':
	case 'e':	goto yy38;
	case 'I':	goto yy39;
	case 'N':	goto yy40;
	case 'i':	goto yy41;
	case 'n':	goto yy42;
	default:	goto yy5;
	}
yy9:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy43;
	case ',':	goto yy45;
	case '.':	goto yy36;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy47;
	case '8':
	case '9':	goto yy48;
	case ':':	goto yy49;
	case 'x':	goto yy50;
	default:	goto yy5;
	}
yy10:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy43;
	case ',':	goto yy27;
	case '.':	goto yy36;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy51;
	case ':':	goto yy49;
	default:	goto yy5;
	}
yy11:
	yych = *(marker = ++cursor);
	switch (yych) {
	case '<':	goto yy52;
	default:	goto yy5;
	}
yy12:
	yych = *++cursor;
	if (yych <= 0x00) goto yy53;
	goto yy5;
yy13:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 'A':	goto yy55;
	case 'a':	goto yy56;
	default:	goto yy5;
	}
yy14:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy57;
	case 'O':
	case 'o':	goto yy59;
	case 'U':	goto yy60;
	case 'u':	goto yy61;
	default:	goto yy5;
	}
yy15:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 'F':	goto yy62;
	case 'N':
	case 'n':	goto yy63;
	case 'f':	goto yy64;
	default:	goto yy5;
	}
yy16:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 'R':	goto yy65;
	case 'r':	goto yy66;
	default:	goto yy5;
	}
yy17:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy67;
	case 'E':	goto yy69;
	case 'e':	goto yy70;
	default:	goto yy5;
	}
yy18:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 'a':	goto yy56;
	default:	goto yy5;
	}
yy19:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy57;
	case 'o':	goto yy59;
	case 'u':	goto yy61;
	default:	goto yy5;
	}
yy20:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 'f':	goto yy64;
	case 'n':	goto yy63;
	default:	goto yy5;
	}
yy21:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 'r':	goto yy66;
	default:	goto yy5;
	}
yy22:
	yych = *(marker = ++cursor);
	switch (yych) {
	case 0x00:	goto yy67;
	case 'e':	goto yy70;
	default:	goto yy5;
	}
yy23:
	yych = *++cursor;
	if (yych <= 0x00) goto yy2;
	goto yy5;
yy24:
	yych = *++cursor;
	switch (yych) {
	case '.':	goto yy34;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy36;
	case 'E':
	case 'e':	goto yy38;
	case 'I':	goto yy39;
	case 'i':	goto yy41;
	default:	goto yy33;
	}
yy25:
	cursor = marker;
	goto yy5;
yy26:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy43;
	case 'x':	goto yy50;
	default:	goto yy46;
	}
yy27:
	yych = *++cursor;
yy28:
	switch (yych) {
	case 0x00:	goto yy43;
	case ',':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy27;
	case '.':	goto yy36;
	case ':':	goto yy49;
	default:	goto yy25;
	}
yy29:
	yych = *++cursor;
	switch (yych) {
	case '.':	goto yy34;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy36;
	case 'E':
	case 'e':	goto yy38;
	case 'I':	goto yy73;
	case 'i':	goto yy74;
	default:	goto yy33;
	}
yy30:
	++cursor;
#line 76 "implicit.re"
	{   return "float#fix"; }
#line 322 "implicit.c"
yy32:
	yych = *++cursor;
yy33:
	switch (yych) {
	case 0x00:	goto yy30;
	case ',':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy32;
	default:	goto yy25;
	}
yy34:
	yych = *++cursor;
	switch (yych) {
	case '.':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy34;
	case 'E':
	case 'e':	goto yy38;
	default:	goto yy25;
	}
yy36:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy30;
	case ',':	goto yy32;
	case '.':	goto yy34;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy36;
	case 'E':
	case 'e':	goto yy38;
	default:	goto yy25;
	}
yy38:
	yych = *++cursor;
	switch (yych) {
	case '+':
	case '-':	goto yy75;
	default:	goto yy25;
	}
yy39:
	yych = *++cursor;
	switch (yych) {
	case 'N':	goto yy76;
	case 'n':	goto yy77;
	default:	goto yy25;
	}
yy40:
	yych = *++cursor;
	switch (yych) {
	case 'A':
	case 'a':	goto yy78;
	default:	goto yy25;
	}
yy41:
	yych = *++cursor;
	switch (yych) {
	case 'n':	goto yy77;
	default:	goto yy25;
	}
yy42:
	yych = *++cursor;
	switch (yych) {
	case 'a':	goto yy79;
	default:	goto yy25;
	}
yy43:
	++cursor;
#line 74 "implicit.re"
	{   return "int"; }
#line 416 "implicit.c"
yy45:
	yych = *++cursor;
yy46:
	switch (yych) {
	case 0x00:	goto yy80;
	case ',':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy45;
	case '.':	goto yy36;
	case '8':
	case '9':	goto yy71;
	case ':':	goto yy49;
	default:	goto yy25;
	}
yy47:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy82;
	case '8':
	case '9':	goto yy83;
	default:	goto yy46;
	}
yy48:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy83;
	default:	goto yy72;
	}
yy49:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':	goto yy84;
	case '6':
	case '7':
	case '8':
	case '9':	goto yy85;
	default:	goto yy25;
	}
yy50:
	yych = *++cursor;
	if (yych <= 0x00) goto yy25;
	goto yy87;
yy51:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy88;
	default:	goto yy28;
	}
yy52:
	yych = *++cursor;
	if (yych <= 0x00) goto yy89;
	goto yy25;
yy53:
	++cursor;
#line 100 "implicit.re"
	{   return "default"; }
#line 509 "implicit.c"
yy55:
	yych = *++cursor;
	switch (yych) {
	case 'L':	goto yy91;
	default:	goto yy25;
	}
yy56:
	yych = *++cursor;
	switch (yych) {
	case 'l':	goto yy92;
	default:	goto yy25;
	}
yy57:
	++cursor;
#line 62 "implicit.re"
	{   return "bool#no"; }
#line 526 "implicit.c"
yy59:
	yych = *++cursor;
	if (yych <= 0x00) goto yy57;
	goto yy25;
yy60:
	yych = *++cursor;
	switch (yych) {
	case 'L':	goto yy93;
	default:	goto yy25;
	}
yy61:
	yych = *++cursor;
	switch (yych) {
	case 'l':	goto yy94;
	default:	goto yy25;
	}
yy62:
	yych = *++cursor;
	switch (yych) {
	case 'F':	goto yy59;
	default:	goto yy25;
	}
yy63:
	yych = *++cursor;
	if (yych <= 0x00) goto yy67;
	goto yy25;
yy64:
	yych = *++cursor;
	switch (yych) {
	case 'f':	goto yy59;
	default:	goto yy25;
	}
yy65:
	yych = *++cursor;
	switch (yych) {
	case 'U':	goto yy95;
	default:	goto yy25;
	}
yy66:
	yych = *++cursor;
	switch (yych) {
	case 'u':	goto yy96;
	default:	goto yy25;
	}
yy67:
	++cursor;
#line 60 "implicit.re"
	{   return "bool#yes"; }
#line 575 "implicit.c"
yy69:
	yych = *++cursor;
	switch (yych) {
	case 'S':	goto yy63;
	default:	goto yy25;
	}
yy70:
	yych = *++cursor;
	switch (yych) {
	case 's':	goto yy63;
	default:	goto yy25;
	}
yy71:
	yych = *++cursor;
yy72:
	switch (yych) {
	case ',':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy71;
	case '.':	goto yy36;
	case ':':	goto yy49;
	default:	goto yy25;
	}
yy73:
	yych = *++cursor;
	switch (yych) {
	case 'N':	goto yy97;
	case 'n':	goto yy98;
	default:	goto yy25;
	}
yy74:
	yych = *++cursor;
	switch (yych) {
	case 'n':	goto yy98;
	default:	goto yy25;
	}
yy75:
	yych = *++cursor;
	if (yych <= 0x00) goto yy25;
	goto yy100;
yy76:
	yych = *++cursor;
	switch (yych) {
	case 'F':	goto yy101;
	default:	goto yy25;
	}
yy77:
	yych = *++cursor;
	switch (yych) {
	case 'f':	goto yy101;
	default:	goto yy25;
	}
yy78:
	yych = *++cursor;
	switch (yych) {
	case 'N':	goto yy102;
	default:	goto yy25;
	}
yy79:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy103;
	case '.':	goto yy105;
	case 'n':	goto yy102;
	default:	goto yy25;
	}
yy80:
	++cursor;
#line 68 "implicit.re"
	{   return "int#oct"; }
#line 654 "implicit.c"
yy82:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':	goto yy106;
	case '8':
	case '9':	goto yy107;
	default:	goto yy46;
	}
yy83:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy107;
	default:	goto yy72;
	}
yy84:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy108;
	case '.':	goto yy110;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy85;
	case ':':	goto yy49;
	default:	goto yy25;
	}
yy85:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy108;
	case '.':	goto yy110;
	case ':':	goto yy49;
	default:	goto yy25;
	}
yy86:
	yych = *++cursor;
yy87:
	switch (yych) {
	case 0x00:	goto yy112;
	case ',':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':
	case 'A':
	case 'B':
	case 'C':
	case 'D':
	case 'E':
	case 'F':
	case 'a':
	case 'b':
	case 'c':
	case 'd':
	case 'e':
	case 'f':	goto yy86;
	default:	goto yy25;
	}
yy88:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy114;
	default:	goto yy28;
	}
yy89:
	++cursor;
#line 102 "implicit.re"
	{   return "merge"; }
#line 760 "implicit.c"
yy91:
	yych = *++cursor;
	switch (yych) {
	case 'S':	goto yy115;
	default:	goto yy25;
	}
yy92:
	yych = *++cursor;
	switch (yych) {
	case 's':	goto yy116;
	default:	goto yy25;
	}
yy93:
	yych = *++cursor;
	switch (yych) {
	case 'L':	goto yy117;
	default:	goto yy25;
	}
yy94:
	yych = *++cursor;
	switch (yych) {
	case 'l':	goto yy117;
	default:	goto yy25;
	}
yy95:
	yych = *++cursor;
	switch (yych) {
	case 'E':	goto yy63;
	default:	goto yy25;
	}
yy96:
	yych = *++cursor;
	switch (yych) {
	case 'e':	goto yy63;
	default:	goto yy25;
	}
yy97:
	yych = *++cursor;
	switch (yych) {
	case 'F':	goto yy118;
	default:	goto yy25;
	}
yy98:
	yych = *++cursor;
	switch (yych) {
	case 'f':	goto yy118;
	default:	goto yy25;
	}
yy99:
	yych = *++cursor;
yy100:
	switch (yych) {
	case 0x00:	goto yy119;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy99;
	default:	goto yy25;
	}
yy101:
	yych = *++cursor;
	if (yych <= 0x00) goto yy121;
	goto yy25;
yy102:
	yych = *++cursor;
	if (yych <= 0x00) goto yy123;
	goto yy25;
yy103:
	++cursor;
#line 64 "implicit.re"
	{   return "bool#na"; }
#line 838 "implicit.c"
yy105:
	yych = *++cursor;
	switch (yych) {
	case 'c':	goto yy125;
	case 'i':	goto yy126;
	case 'r':	goto yy127;
	default:	goto yy25;
	}
yy106:
	yych = *++cursor;
	switch (yych) {
	case '-':	goto yy128;
	default:	goto yy46;
	}
yy107:
	yych = *++cursor;
	switch (yych) {
	case '-':	goto yy128;
	default:	goto yy72;
	}
yy108:
	++cursor;
#line 70 "implicit.re"
	{   return "int#base60"; }
#line 863 "implicit.c"
yy110:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy129;
	case ',':
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy110;
	default:	goto yy25;
	}
yy112:
	++cursor;
#line 66 "implicit.re"
	{   return "int#hex"; }
#line 885 "implicit.c"
yy114:
	yych = *++cursor;
	switch (yych) {
	case '-':	goto yy128;
	default:	goto yy28;
	}
yy115:
	yych = *++cursor;
	switch (yych) {
	case 'E':	goto yy59;
	default:	goto yy25;
	}
yy116:
	yych = *++cursor;
	switch (yych) {
	case 'e':	goto yy59;
	default:	goto yy25;
	}
yy117:
	yych = *++cursor;
	if (yych <= 0x00) goto yy2;
	goto yy25;
yy118:
	yych = *++cursor;
	if (yych <= 0x00) goto yy131;
	goto yy25;
yy119:
	++cursor;
#line 78 "implicit.re"
	{   return "float#exp"; }
#line 916 "implicit.c"
yy121:
	++cursor;
#line 82 "implicit.re"
	{   return "float#inf"; }
#line 921 "implicit.c"
yy123:
	++cursor;
#line 86 "implicit.re"
	{   return "float#nan"; }
#line 926 "implicit.c"
yy125:
	yych = *++cursor;
	switch (yych) {
	case 'h':	goto yy133;
	default:	goto yy25;
	}
yy126:
	yych = *++cursor;
	switch (yych) {
	case 'n':	goto yy134;
	default:	goto yy25;
	}
yy127:
	yych = *++cursor;
	switch (yych) {
	case 'e':	goto yy135;
	default:	goto yy25;
	}
yy128:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy136;
	default:	goto yy25;
	}
yy129:
	++cursor;
#line 80 "implicit.re"
	{   return "float#base60"; }
#line 964 "implicit.c"
yy131:
	++cursor;
#line 84 "implicit.re"
	{   return "float#neginf"; }
#line 969 "implicit.c"
yy133:
	yych = *++cursor;
	switch (yych) {
	case 'a':	goto yy137;
	default:	goto yy25;
	}
yy134:
	yych = *++cursor;
	switch (yych) {
	case 't':	goto yy138;
	default:	goto yy25;
	}
yy135:
	yych = *++cursor;
	switch (yych) {
	case 'a':	goto yy139;
	default:	goto yy25;
	}
yy136:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy140;
	default:	goto yy25;
	}
yy137:
	yych = *++cursor;
	switch (yych) {
	case 'r':	goto yy141;
	default:	goto yy25;
	}
yy138:
	yych = *++cursor;
	switch (yych) {
	case 'e':	goto yy142;
	default:	goto yy25;
	}
yy139:
	yych = *++cursor;
	switch (yych) {
	case 'l':	goto yy143;
	default:	goto yy25;
	}
yy140:
	yych = *++cursor;
	switch (yych) {
	case '-':	goto yy144;
	default:	goto yy25;
	}
yy141:
	yych = *++cursor;
	switch (yych) {
	case 'a':	goto yy145;
	default:	goto yy25;
	}
yy142:
	yych = *++cursor;
	switch (yych) {
	case 'g':	goto yy146;
	default:	goto yy25;
	}
yy143:
	yych = *++cursor;
	if (yych <= 0x00) goto yy147;
	goto yy25;
yy144:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy149;
	default:	goto yy25;
	}
yy145:
	yych = *++cursor;
	switch (yych) {
	case 'c':	goto yy150;
	default:	goto yy25;
	}
yy146:
	yych = *++cursor;
	switch (yych) {
	case 'e':	goto yy151;
	default:	goto yy25;
	}
yy147:
	++cursor;
#line 88 "implicit.re"
	{   return "float#na"; }
#line 1074 "implicit.c"
yy149:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy152;
	default:	goto yy25;
	}
yy150:
	yych = *++cursor;
	switch (yych) {
	case 't':	goto yy153;
	default:	goto yy25;
	}
yy151:
	yych = *++cursor;
	switch (yych) {
	case 'r':	goto yy154;
	default:	goto yy25;
	}
yy152:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy155;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy25;
	case 'T':
	case 't':	goto yy159;
	default:	goto yy158;
	}
yy153:
	yych = *++cursor;
	switch (yych) {
	case 'e':	goto yy160;
	default:	goto yy25;
	}
yy154:
	yych = *++cursor;
	if (yych <= 0x00) goto yy161;
	goto yy25;
yy155:
	++cursor;
#line 90 "implicit.re"
	{   return "timestamp#ymd"; }
#line 1134 "implicit.c"
yy157:
	yych = *++cursor;
yy158:
	switch (yych) {
	case '\t':
	case ' ':	goto yy157;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy163;
	default:	goto yy25;
	}
yy159:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy164;
	default:	goto yy25;
	}
yy160:
	yych = *++cursor;
	switch (yych) {
	case 'r':	goto yy165;
	default:	goto yy25;
	}
yy161:
	++cursor;
#line 72 "implicit.re"
	{   return "int#na"; }
#line 1178 "implicit.c"
yy163:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy166;
	default:	goto yy25;
	}
yy164:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy167;
	default:	goto yy25;
	}
yy165:
	yych = *++cursor;
	if (yych <= 0x00) goto yy168;
	goto yy25;
yy166:
	yych = *++cursor;
	switch (yych) {
	case ':':	goto yy170;
	default:	goto yy25;
	}
yy167:
	yych = *++cursor;
	switch (yych) {
	case ':':	goto yy171;
	default:	goto yy25;
	}
yy168:
	++cursor;
#line 98 "implicit.re"
	{   return "str#na"; }
#line 1229 "implicit.c"
yy170:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy172;
	default:	goto yy25;
	}
yy171:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy173;
	default:	goto yy25;
	}
yy172:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy174;
	default:	goto yy25;
	}
yy173:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy175;
	default:	goto yy25;
	}
yy174:
	yych = *++cursor;
	switch (yych) {
	case ':':	goto yy176;
	default:	goto yy25;
	}
yy175:
	yych = *++cursor;
	switch (yych) {
	case ':':	goto yy177;
	default:	goto yy25;
	}
yy176:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy178;
	default:	goto yy25;
	}
yy177:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy179;
	default:	goto yy25;
	}
yy178:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy180;
	default:	goto yy25;
	}
yy179:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy181;
	default:	goto yy25;
	}
yy180:
	yych = *++cursor;
	switch (yych) {
	case '.':	goto yy184;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy25;
	default:	goto yy185;
	}
yy181:
	yych = *++cursor;
	switch (yych) {
	case '.':	goto yy187;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy25;
	default:	goto yy188;
	}
yy182:
	yych = *++cursor;
	switch (yych) {
	case '\t':
	case ' ':	goto yy182;
	case '+':
	case '-':	goto yy190;
	case 'Z':	goto yy191;
	default:	goto yy25;
	}
yy184:
	yych = *++cursor;
yy185:
	switch (yych) {
	case '\t':
	case ' ':	goto yy182;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy184;
	default:	goto yy25;
	}
yy186:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy192;
	default:	goto yy25;
	}
yy187:
	yych = *++cursor;
yy188:
	switch (yych) {
	case '+':
	case '-':	goto yy186;
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy187;
	case 'Z':	goto yy189;
	default:	goto yy25;
	}
yy189:
	yych = *++cursor;
	if (yych <= 0x00) goto yy193;
	goto yy25;
yy190:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy195;
	default:	goto yy25;
	}
yy191:
	yych = *++cursor;
	if (yych <= 0x00) goto yy196;
	goto yy25;
yy192:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy198;
	default:	goto yy25;
	}
yy193:
	++cursor;
#line 92 "implicit.re"
	{   return "timestamp#iso8601"; }
#line 1498 "implicit.c"
yy195:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy199;
	default:	goto yy25;
	}
yy196:
	++cursor;
#line 94 "implicit.re"
	{   return "timestamp#spaced"; }
#line 1518 "implicit.c"
yy198:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy193;
	case ':':	goto yy200;
	default:	goto yy25;
	}
yy199:
	yych = *++cursor;
	switch (yych) {
	case 0x00:	goto yy196;
	case ':':	goto yy201;
	default:	goto yy25;
	}
yy200:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy202;
	default:	goto yy25;
	}
yy201:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy203;
	default:	goto yy25;
	}
yy202:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy189;
	default:	goto yy25;
	}
yy203:
	yych = *++cursor;
	switch (yych) {
	case '0':
	case '1':
	case '2':
	case '3':
	case '4':
	case '5':
	case '6':
	case '7':
	case '8':
	case '9':	goto yy191;
	default:	goto yy25;
	}
}
#line 106 "implicit.re"


}
